@@ -1,4 +1,4 @@
-from .computation_engine import apply, join, summarize, Engine, files_from
+from .computation_engine import apply, join, summarize, Engine, files_from, DelayedException
 from .fs_cache import CacheBuilder
 from .std_logger import get_logger
 
